@@ -2,6 +2,8 @@
 from __future__ import unicode_literals
 
 import os
+import sys
+sys.path.insert(0, os.path.abspath('..'))
 
 
 extensions = [
@@ -15,19 +17,20 @@ extensions = [
     'sphinx.ext.todo',
     'sphinx.ext.viewcode',
 ]
+autodoc_mock_imports = ["numpy", 'pandas']
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'finance_calculator'
 year = '2020'
 author = 'Surya Prakash'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.0.1'
+version = release = '0.0.2'
 
 pygments_style = 'trac'
 templates_path = ['.']
 extlinks = {
-    'issue': ('https://github.com/sprksh/finance_calculator/issues/%s', '#'),
-    'pr': ('https://github.com/sprksh/finance_calculator/pull/%s', 'PR #'),
+    'issue': ('https://github.com/sprksh/finance-calculator/issues/%s', '#'),
+    'pr': ('https://github.com/sprksh/finance-calculator/pull/%s', 'PR #'),
 }
 # on_rtd is whether we are on readthedocs.org
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
